ClickHousePool class

Constructors

ClickHousePool({required ClickHouseOptions options, int maxOpen = 10, int? maxIdle, Duration maxLifetime = const Duration(hours: 1), Duration? idleTimeout = const Duration(minutes: 10), Duration? waitTimeout, Duration healthCheckInterval = const Duration(seconds: 30), bool freeBufferOnRelease = false})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stats PoolStats
no setter

Methods

asyncInsert(String sql, {bool wait = false, Map<String, Object?>? settings, Map<String, String>? parameters}) Future<void>
close() Future<void>
exec(String sql, {String? queryId, String? quotaKey, Map<String, Object?>? settings, Map<String, String>? parameters, void onProgress(Progress)?, Duration? timeout, List<ExternalTable>? externalTables, List<Object?>? args}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ping() Future<bool>
prepareBatch(String sql, {String? queryId, String? quotaKey, Map<String, Object?>? settings, Map<String, String>? parameters, bool releaseConnection = false, bool closeOnFlush = false}) Future<ClickHouseBatch>
query(String sql, {String? queryId, String? quotaKey, Map<String, Object?>? settings, Map<String, String>? parameters, void onProgress(Progress)?, Duration? timeout, List<ExternalTable>? externalTables, List<Object?>? args}) Future<Rows>
serverVersion() Future<ServerHandshake>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited