PoolStats class

Annotations
  • @immutable

Constructors

PoolStats({required int open, required int idle, required int maxOpen, required int maxIdle, required int waiters})
const

Properties

hashCode int
The hash code for this object.
no setteroverride
idle int
final
maxIdle int
final
maxOpen int
final
open int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
waiters int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override