ServerContext class
Constructors
Properties
- effectiveTimezone → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- revision → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supportsFlatDynamicJSON → bool
-
no setter
- timezone → String
-
final
- userTimezone → String?
-
final
- version → ServerVersion
-
no setter
- versionMajor → int
-
final
- versionMinor → int
-
final
- versionPatch → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
withUserTimezone(
String? tz) → ServerContext
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited